
.. py:currentmodule:: pythreejs

CloneArray
====================================================

.. Use autoclass to fill any memebers not manually specified.
   This ensures it picks up any members in overridden classes.

.. autohastraits:: CloneArray(original=None, positions=[], merge=False, )
    :members:
    :undoc-members:


    Inherits :py:class:`~pythreejs.Object3D`.

    Three.js docs: https://threejs.org/docs/#api/objects/CloneArray


    .. py:attribute:: original

        .. sourcecode:: python

            Instance(Object3D, allow_none=True).tag(sync=True, **widget_serialization)

    .. py:attribute:: positions

        .. sourcecode:: python

            List(trait=List()).tag(sync=True)

    .. py:attribute:: merge

        .. sourcecode:: python

            Bool(False, allow_none=False).tag(sync=True)

